# ytmp3-client

Python client library for YT-MP3 API.

## Install

```
pip install ytmp3
```

## Usage

```python
from ytmp3 import YTtoMP3

client = YTtoMP3()
result = client.convert("rDeQr-DC4Xo")
print(result)
```
